# STYLOTOOL - an easy-to-use stylistic device detection tool for stylometry

An easy-to-use package for detecting stylistic devices in text. This package is designed to be used in stylometry, the study of linguistic style.

For those proficient in python, this package provides a collection of approaches to detect stylistic devices in text. For those less proficient in python, this package provides a simple interface to detect stylistic devices in text with simple commands and user-friendly configuration.
For an example on usage, see `example_chiasmus.sh` and the config file `example_config.json`.

# Installation
The package is available on PyPi and can be installed using pip.
TODO: add installation instructions

# Participation
The package is free and open-source software and contributions are very welcome.
It is designed to be a living project that is constantly improved and extended.
If you have implemented your own stylistic device detector, please consider contributing it to the package.
Also, if you have any suggestions for improvements or if you find any bugs, please open an issue on the GitHub page.
